@@ -29,7 +29,7 @@ class FunMangaCom(Provider, Std):
         return self._cover_from_content('img.img-responsive.mobile-img')
 
     def prepare_cookies(self):
-        self.cf_protect(self.get_url())
+        self.cf_scrape(self.get_url())
 
 
 main = FunMangaCom
