@@ -4,10 +4,6 @@ from .helpers.std import Std
 
 class MangaIndoWebId(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index()
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         selector = r'-chapter-([^/]+)'
         return self.re.search(selector, self.chapter).group(1)
